/***************************************************************************
 *   Copyright (C) 2003 by Antonio Fasolato                                *
 *   Antonio.Fasolato@poste.it                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>

#include <kfiledialog.h>
#include <knuminput.h>
#include <kcombobox.h>
#include <kcolorbutton.h>

#include "optiondialog.h"
#include <iostream>
using namespace std;

OptionDialog::OptionDialog(Options &o)
 : OptionDialogBase(), options(o)
{
	if(!options.isEmpty())  //I have old settings: I have to initialize the dialog
		initializeOptions(options);
}


void OptionDialog::selectOutputFile() {
	KFileDialog *d=new KFileDialog(QString::null,"*.ps *.eps *.svg *.pgm *.pat *.fig|Vector images",this,"Select the output vector image",true);

	d->exec();

	if(d->result()==QDialog::Accepted) {
		outputFileName->setText(d->selectedFile());
	}
}

void OptionDialog::exitOk(){
	options.clear();
	/* ---saving the options--- */

	//input-output
	options.setValue("blackLevel",QString::number(blackLevel->value()));
	options.setValue("invertInput",(invertInput->isChecked())?"y":"n");
	options.setValue("outputFileName",outputFileName->text());
	options.setValue("outputFormat",outputFormat->currentText());
	if(outputFormat->currentText()=="eps" || outputFormat->currentText()=="postscript") {  //ps options
		options.setValue("pageSize",pageSize->currentText());
		options.setValue("optimizedNumericalCode",(optimizedNumericalCode->isChecked())?"y":"n");
		QButton *b=compressionLevel->selected();
		if(b->text()=="None")
			options.setValue("compressionLevel","1");
		else if(b->text()=="Level 2")
			options.setValue("compressionLevel","2");
		else
			options.setValue("compressionLevel","3");
	}
	else if(outputFormat->currentText()=="SVG") {  //SVG options
		options.setValue("SVGGroup",(SVGGroup->isChecked())?"y":"n");
	}
	else if(outputFormat->currentText()=="Gimp path") {  //Gimp options
	}
	else if(outputFormat->currentText()=="Xfig") {  //Xfig options
	}
	else {  //pgm options
		options.setValue("antialiasGamma",QString::number(antialiasGamma->value()));
		//Scale
		if(scaleAll->isEnabled())
			options.setValue("scale",QString::number(scaleAll->value()));
		else
			options.setValue("scale",QString::number(scaleX->value())+"x"+QString::number(scaleY->value()));
	}

	//Color
	QColor c=foregroundBtn->color();
	options.setValue("foregroundBtn",c.name());
	options.setValue("opaque",(opaque->isChecked())?"y":"n");
	c=backgroundBtn->color();
	options.setValue("backgroundBtn",c.name());

	//Algorithm
	options.setValue("policy",policy->currentText());
	options.setValue("despeckle",QString::number(despeckle->value()));
	options.setValue("cornerThreshold",QString::number(cornerThreshold->value()));
	options.setValue("optimizationTolerance",QString::number(optimizationTolerance->value()));
	options.setValue("outputQuantization",QString::number(outputQuantization->value()));
	options.setValue("curveOptimization",(curveOptimization->isChecked())?"y":"n");

	//Transformation
	options.setValue("width",QString::number(width->value()));
	options.setValue("height",QString::number(height->value()));
	options.setValue("stretch",QString::number(stretch->value()));
	options.setValue("rotation",QString::number(rotation->value()));

	//Resolution
	if(resolutionAll->isEnabled())
		options.setValue("resolution",QString::number(resolutionAll->value()));
	else
		options.setValue("resolution",QString::number(resolutionX->value())+"x"+QString::number(resolutionY->value()));

	//Margins
	if(marginsAll->isEnabled())
		options.setValue("margins",QString::number(marginsAll->value()));
 	else
 		options.setValue("margins",QString::number(marginsL->value())+"x"+QString::number(marginsR->value())+"x"+ QString::number(marginsT->value())+"x"+QString::number(marginsB->value()));

	accept();
}

void OptionDialog::initializeOptions(Options &opt) {
	//input
	blackLevel->setValue((opt["blackLevel"]).toFloat());
	invertInput->setChecked(opt["invertInput"]=="y");

	//output
	outputFileName->setText(opt["outputFileName"]);
	outputFormat->setCurrentText(opt["outputFormat"]);
	if(opt["outputFormat"]=="eps" || opt["outputFormat"]=="postscript") {       //eps format
		pageSize->setCurrentText(opt["pageSize"]);
		optimizedNumericalCode->setChecked(opt["optimizedNumericalCode"]=="y");
		level1->setChecked(opt["compressionLevel"]=="1");
		level2->setChecked(opt["compressionLevel"]=="2");
		level3->setChecked(opt["compressionLevel"]=="3");
	}
	else if(opt["outputFormat"]=="SVG")            //SVG format
		SVGGroup->setChecked(opt["SVGGroup"]=="y");
	else if(opt["outputFormat"]=="Gimp path");          //Gimp format
	else if(opt["outputFormat"]=="Xfig path");          //Xfig format
	else  {                                                              //pgm format
		antialiasGamma->setValue((opt["antialiasGamma"]).toFloat());
		//Scale
		if((opt["scale"]).find('x')==-1) {   //only one value
			scaleAll->setValue((opt["scale"]).toFloat());
			scaleAllBTN->setChecked(true);
		}
		else {
			QString tmp=opt["scale"];
			scaleX->setValue((tmp.section('x',0,0)).toFloat());
			scaleY->setValue((tmp.section('x',1,1)).toFloat());
			scaleXYBTN->setChecked(true);
		}
	}

	//Color
	foregroundBtn->setColor(QColor(opt["foregroundBtn"]));
	opaque->setChecked(opt["opaque"]=="y");
	backgroundBtn->setColor(QColor(opt["backgroundBtn"]));

	//Algorithm
	policy->setCurrentText(opt["policy"]);
	despeckle->setValue((opt["despeckle"]).toInt());
	cornerThreshold->setValue((opt["cornerThreshold"]).toFloat());
	optimizationTolerance->setValue((opt["optimizationTolerance"]).toFloat());
	outputQuantization->setValue((opt["outputQuantization"]).toInt());
	curveOptimization->setChecked(opt["curveOptimization"]=="y");

	//Transformation
	width->setValue((opt["width"]).toFloat());
	height->setValue((opt["height"]).toFloat());
	stretch->setValue((opt["stretch"]).toFloat());
	rotation->setValue((opt["rotation"]).toFloat());

	//Resolution
	if((opt["resolution"]).find('x')==-1) { //only one value
		resolutionAll->setValue((opt["resolution"]).toFloat());
		resolutionAllBTN->setChecked(true);
	}
	else {
		QString tmp=opt["resolution"];
		resolutionX->setValue((tmp.section('x',0,0)).toFloat());
		resolutionY->setValue((tmp.section('x',1,1)).toFloat());
		resolutionXYBTN->setChecked(true);
	}

	//Margins
	if((opt["margins"]).find('x')==-1) {   //only one value
		marginsAll->setValue((opt["margins"]).toFloat());
		marginsAllBTN->setChecked(true);
	}
	else {
		QString tmp=opt["margins"];
		marginsL->setValue((tmp.section('x',0,0)).toFloat());
		marginsR->setValue((tmp.section('x',1,1)).toFloat());
		marginsT->setValue((tmp.section('x',2,2)).toFloat());
		marginsB->setValue((tmp.section('x',3,3)).toFloat());
		marginsXYBTN->setChecked(true);
	}
}

Options *OptionDialog::createDefaultOptions(){
	Options *toReturn=new Options();
	return toReturn;
}

void OptionDialog::defaults(){
	Options *o=Options::defaultOptions();
	initializeOptions(*o);
	delete o;
}
