/*
 * Copyright (C) 2003 Antonio Fasolato <Antonio.Fasolato@poste.it>
 */

#ifndef _POTRACEGUI_H_
#define _POTRACEGUI_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kmainwindow.h>
#include <kurl.h>

#include <qstringlist.h>
#include <qprocess.h>

#include "potraceGuiBase.h"
#include "optiondialog.h"
#include "options.h"
#include "settings.h"

/**
 * This is the app's main window (a QDialog, for precision's sake). Here you can select the image to process, its options, the global settings and trace the image.
 * @short Application Main Window
 * @author Antonio Fasolato <Antonio.Fasolato@poste.it>
 * @version 0.1
 */
class PotraceGui : public PotraceGuiBase
{
    Q_OBJECT
public:
    /**
     * Default Constructor. It does nothing in particular, other than create an empty Options object, and a QProcess, that will be the traced image preview.
     * @short Default Constructor
     */
    PotraceGui();

    /**
     * Yes, it's a destructor and, guess what!, it does all the cleaning up before quitting. In particular it stops the preview process, for not leaving it running after the app is closed.
     * @short Default Destructor
     */
    virtual ~PotraceGui();
public slots:

    void selectImageURL(KURL imageURL);

private slots:
    /**
     * Opens a File selection dialog, in which you can select the bitmapped image to trace
     * @short Permits to select an image
     */
    virtual void selectImage();
    /**
     * Used to set potrace's options for the image i.e. how potrace should work on the image.
     * @short Image properties
     */
    virtual void setOptions();
    /**
     * Starts potrace with the defined options, and shows a preview of the result.
     * @short Starts potrace
     */
    virtual void trace();
    /**
     * Opens a dialog to set the global settings.
     * @short App's settings
     */
    virtual void settings();
    void tracerExited();
    void writeCompleted();
    void imageDropped();


private:
	QString filename;
	QStringList createCommandLine();
	QProcess tracer;
    bool aborted;

public:
	Options options; /**< Potrace's options for this image.*/
};

#endif // _POTRACEGUI_H_
